@@ -460,11 +460,12 @@ class DashboardExtractor:
             data: Modified dashboard JSON with placeholders
             output_path: Path to write jsonnet file to
         """
-        json_content = json.dumps(data, indent=2)
+        json_content = json.dumps(data, indent=2, ensure_ascii=False)
 
         if not self._modifications:
             with open(output_path, "w") as f:
                 f.write(json_content)
+                f.write('\n')
             return
 
         # Deduplicate imports
@@ -493,3 +494,4 @@ class DashboardExtractor:
             if local_vars:
                 f.write("\n".join(local_vars) + "\n\n")
             f.write(json_content)
+            f.write('\n')
